#ifndef CLEANL_H

#define CLEANL_H

// The CleanLanguage class will parse any set of input ascii data
// in the english language, look for objectionable words, and replace them
// with non-objectionable words.  It uses a fuzzy string compare routine to
// detect inappropriate language even if it is not spelled exactly
// correctly.  Certainly users can find ways to defeat this parser, but
// it has proven amusing and harmless in the past.  The word lists and
// intermediate strings  are all converted into another alphabet, so you
// shouldn't find yourself offended by the language in the code, or even
// hackers dissassembling it for that matter.
//
// This code makes use of STL for String operations.
//
// OpenSourced July 25, 2000, by John W. Ratcliff (jratcliff@verant.com)
// for FlipCode.com.


#pragma warning( disable:4786 )
#pragma warning(disable:4800) // int forced to bool

#include <string>
#include <vector>

typedef std::string String;
typedef std::vector< String > StringVector;

class Translate; // forward reference ascii translation table.

class CleanLanguage
{
public:
  CleanLanguage(void);
  ~CleanLanguage(void);

  // will analyze an input string for foul language, and will replace
  // objectionable language with non-offending ascii text in the ouput
  // string.  Returns count of the number of offending words found.
  int WashYourMouth(const String &input,String &output) const;

  // Check this potential 'bad' word against the word list.
  // If the word was objectionable it will be replaced with an
  // appropriate alternative in the String 'good'.  If the word
  // is not offensive, then good will simply contain the original
  // string passed.  The return value is the percentage match found
  // between the offending word and one in the database.
  int CheckWord(const String &bad,String &good) const;

  static bool IsAlpha(char c);

  static bool WildCard(const char *wild,const char *match);

private:

  static bool Add(char c,char *clean,int &index,int maxlen);

  Translate   *mTranslate; // translation table.
  StringVector mWords;  // bad words and their alternates.
  unsigned char mWildChar; // wild card character.
};

#endif
